'FFSubmenu=Tools
'FFName=Bilder ausrichten

' ********************************************************************
' BildAusrichtung.vbs (Skript fr FixFoto)
' Funktion:	Gegenseitiges Ausrichten von Bildern aus einer Belichtungsreihe
'
' basierend auf dem SkriptMatchImages.js von Joachim Koopmann
' FF-Version 3.40.72 erforderlich
'
' Copyright Harald Maeckler, Dsseldorf 2013 - 2017
'
' Version 1.06 vom 16.10.2017	- bertragung der IPTC-Daten auf die ausgerichteten Bilder
' Version 1.05 vom 26.09.2017	- bei Option 'Beschnitt' ermittelte Schnittbreite
'									kann um eingebbaren Wert vergrert werden
' Version 1.04 vom 25.09.2017	- Option 'Beschnitt' hinzugefgt
' Version 1.03 vom 29.03.2016	- Skript-URL gem Forenberarbeitung gendert
' Version 1.02 vom 13.04.2013	- bei Start Meldung "Ausrichten wird vorbereitet"
'								- Kurzbeschreibung als PDF
' Version 1.01 vom 12.04.2013	- Retuscheaufruf
' Version 1.00 vom 09.04.2013	- Betaversion
' ********************************************************************

'** Start Text **
'
' Bilder ausrichten
' ==========
' Mit dem Skript werden Bilder einer manuell erstellten Belichtungsreihe gegenei-
' nander ausgerichtet. Nach dem Ausrichten haben alle Bilder die gleiche Gre und
' die Konturen liegen passgenau bereinander. 
' Werden beim Ausrichten Bilder gedreht, knnen schwarze Rnder entstehen. Zur
' Weiterverarbeitung, z.B. mit einem DRI-Programm, sollten die Bilder unbeschnitten
' bernommen werden. Erst beim fertigen Bild kann ein evtl. dann noch bestehender
' Rand abgeschnitten werden.
'
' Ist eine Ausrichtung nicht mglich, kann es sein, dass es zu der Fehlermeldung
' "FFTools.exe funktioniert nicht mehr" kommt. Dann bitte "Abbrechen" bettigen.
' Das Skript lscht darauf evtl. fehlerhaft erstellte Bilder und wird dann ordnungs-
' gem beendet.
'
' Da der verwendete Ausrichtbefehl vorhandene Exif-Daten nicht bertrgt, werden
' diese, wenn mglich, nach dem Ausrichten von den ausgewhlten Bildern in die aus-
' gerichteten Bilder bertragen.
'
' Auswahl
' ----------
' Es wird festgelegt, ob selektierte Bilder der Computeransicht oder der aktuellen
' Bilderliste ausgerichtet werden sollen. Es mssen mindestens 2 Bilder markiert
' werden.
'
' Ausgabe
' ----------
' Die ausgerichteten Bilder werden im gewhlten Bildformat abgelegt. Bei 'ident'
' wird das jeweilige Format der ausgewhlten Bilder bernommen (es bleibt iden-
' tisch).
'
' Ist nicht die Option 'Neuer Name' aktiviert, kann fr die ausgerichteten Bilder
' eine Prfix oder Suffix festgelegt werden.
'
' Bei den ausgerichteten Bildern ergeben sich in der Regel schwarze Rnder. Bei akti-
' vierter Option 'Beschnitt' werden diese abgeschnitten. Die automatisch ermittelten
' Schnittwerte knnen um einen eingebbaren Wert vergrert werden.
'
' Bei aktivierter Option 'Retuscheaufruf' wird nach erfolgreicher Ausrichtung der
' Retuschedialog von FixFoto mit dem dunkelsten Bild im Zielfenster zum 
' 'Quelle klonen' aufgerufen. Dabei wird das hellste Bild in das Quellfenster ge-
' laden. Bevor man beginnt mit dem Pinsel helle Details aus dem Quellfenster in das
' Zielfenster zu bertragen, ist unbedingt darauf zu achten, dass die Option 
' 'Klonpinsel synchron' aktiviert ist.
'
' Neuer Name + 2-st. Nummer
' -----------------------------------
' Mit der Option 'Neuer Name' wird fr die ausgerichteten Bilder statt der Namen
' der ausgewhlten Bilder mit Prfix oder Suffix ein beliebiger anderer Name fest-
' gelegt. Angehngt wird jeweils eine fortlaufende, zweistellige Nummer.
'
' fester Speicherort
' ----------------------
' Standardmig wird als Speicherort fr die ausgerichteten Bilder der Ordner der
' ausgewhlten Bilder verwendet. Mit dieser Option kann ein fester Speicherort
' festgelegt werden. Die Auswahl erfolgt mit dem Befehl '...'.
'
' Update
' =====
' Nach Bettigung der Taste 'Update' wird auf der Downloadseite des Skripts ber-
' prft, ob eine neuere Version vorliegt. Ist dies der Fall, wird angeboten die Down-
' loadseite aufzurufen.
'
' Deinstallation
' =========
' Wird die Entfernung des Skripts gewnscht, kann mit der Tastenkombination
' Alt + D eine Lschroutine aufgerufen werden. Nach einer Sicherheitsabfrage wird
' berprft, ob das zugehrige zip-Archiv im Skriptordner abgelegt ist. Wenn ja,
' wird vor dem Lschen angeboten, davon eine Sicherheitskopie an einem whl-
' barem Speicherort abzulegen. Dann wird die Skriptdatei gelscht und die Datei
' FixFotoScript.ini bereinigt.
'
' Nach manueller Durchfhrung der 'Automatischen Skriptkonfiguration' ist das
' Skript mit allen Komponenten aus der FixFoto-Umgebung entfernt.
'
'
' Benutzung des Skripts auf eigene Gefahr!
'
'  Harald Maeckler
'** Textende **

Option Explicit

'Skriptname
Dim SkriptName
const Skript = "BildAusrichtung"
const RegSchluessel = "FF_BildAusrichtung"

'Updatekonstanten und Variable
const SkriptVersion = "1.06"
const SkriptURL = "http://www.ffsf.de/resources/bilder-ausrichten.138/"
Dim UrlVersion,UrlV_Zahl,SkriptV_Zahl,SkriptEnde

'Objekte und Konstante
Dim objFS,WshShell
Dim Text,LaengeMax
Const ForReading = 1, ForWriting = 2, ForAppending = 8

'Lschroutine
Dim TempFile,SkriptKill	 : SkriptKill = false

'Allgemeine Deklarationen
Dim Anzeige,Antwort,Abbruch
Dim ListArray,element,msg

'Skriptkonstante und -Variable
Const BfrmtAuswahl = "JPG,JP2,TIF,BMP,PNG,ident"
Dim flag_sBCA,flag_sBaB
Dim Bfrmt,flag_Praefix,PraefixTxt,flag_Suffix,SuffixTxt,flag_Retusche
Dim flag_NeuerName,NeuerNameTxt
Dim flag_Speicherort,SpeicherortTxt
Dim mldAllgemein,mldStart,mldAusrichten,mldRetusche
Dim flag_Beschnitt,BS_Wert

'Spezielle Variable
Dim Auswahl,infiles,infArray,outfiles,outfArray
Dim hBild,dBild,retAufruf : retAufruf = false

'------------------------------------------------------------------------
Set objFS = CreateObject("Scripting.FileSystemObject")
Set WshShell = CreateObject("WScript.Shell")

call Main

Set objFS = nothing
Set WshShell = nothing
'------------------------------------------------------------------------
Sub Main
Dim flag_Ausrichten : flag_Ausrichten = false

on error resume next							'Kontrolle ob Skript in FF-Umgebung gestartet wurde
	FF_GetScriptPath
 	if Err.Number > 0 then
		msgbox "Das Skript funktioniert nur in der Programmumgebung von FixFoto!",vbCritical,"Abbruch"
		exit sub
	end if
on error goto 0

if objFS.FileExists(FF_GetScriptPath & "\" & Skript & ".vbs") then
	SkriptName = Skript & ".vbs"
elseif objFS.FileExists(FF_GetScriptPath & "\" & Skript & ".vbe") then
	SkriptName = Skript & ".vbe"
else
	msgbox "Das Skript wurde umbenannt!",vbCritical,"Abbruch"
	exit sub
end if

if not Version_OK("3.40.72") then
	msgbox 	"Fr das Ausrichten von Bildern ist" & vbNewLine &_
			"mindestens FixFoto-Version 3.40.72 erforderlich!",vbExclamation,"Abbruch"
	exit sub
end if

mldAllgemein  = FF_GetScriptPath & "\MeckiScript\BildAusrichtung\Skriptinfo_Allgemein.png"
mldStart      = FF_GetScriptPath & "\MeckiScript\BildAusrichtung\Skriptinfo_Start.png"
mldAusrichten = FF_GetScriptPath & "\MeckiScript\BildAusrichtung\Skriptinfo_Ausrichten.png"
mldRetusche   = FF_GetScriptPath & "\MeckiScript\BildAusrichtung\Skriptinfo_Retusche.png"

msg =	"Bei aktivierter Option 'Retuscheaufruf' wird nach erfolgreicher Ausrichtung" & vbNewLine &_
		"der Retuschedialog von FixFoto mit dem dunkelsten Bild im Zielfenster zum" & vbNewLine &_
		"'Quelle klonen' aufgerufen. Dabei wird das hellste Bild in das Quellfenster ge-" & vbNewLine &_
		"laden. Bevor man beginnt mit dem Pinsel helle Details aus dem Quellfenster in" & vbNewLine &_
		"das Zielfenster zu bertragen, ist unbedingt darauf zu achten, dass die" & vbNewLine &_
		"Option 'Klonpinsel synchron' aktiviert ist."

'** Start Dialog Bilder ausrichten **
FF_AddDialog "Bilder ausrichten",205,146
FF_AddControl "Bilder ausrichten","Auswahl","GROUP",5,5,115,32
FF_AddControl "Bilder ausrichten","flag_sBCA","BOOL",10,16,8,8
FF_SetControlStyle "Bilder ausrichten","flag_sBCA",16384
FF_AddControl "Bilder ausrichten","flag_sBaB","BOOL",10,26,8,8
FF_SetControlStyle "Bilder ausrichten","flag_sBaB",16384
FF_AddControl "Bilder ausrichten","selektierte Bilder der Computeransicht","STATIC",22,15,94,10
FF_AddControl "Bilder ausrichten","selektierte Bilder der aktiven Bilderliste","STATIC",22,25,94,10
FF_AddControl "Bilder ausrichten","Ausgabe","GROUP",127,5,73,60
FF_AddControl "Bilder ausrichten","Bildformat","STATIC",132,15,26,10
FF_AddControl "Bilder ausrichten","Bfrmt","COMBO",165,15,30,10
FF_AddControl "Bilder ausrichten","flag_Praefix","BOOL",132,29,8,8
FF_SetControlStyle "Bilder ausrichten","flag_Praefix",16384
FF_AddControl "Bilder ausrichten","Prfix","STATIC",143,28,20,10
FF_AddControl "Bilder ausrichten","PraefixTxt","SLEDIT",165,28,30,10
FF_AddControl "Bilder ausrichten","flag_Suffix","BOOL",132,41,8,8
FF_SetControlStyle "Bilder ausrichten","flag_Suffix",16384
FF_AddControl "Bilder ausrichten","Suffix","STATIC",143,40,20,10
FF_AddControl "Bilder ausrichten","SuffixTxt","SLEDIT",165,40,30,10
FF_AddControl "Bilder ausrichten","flag_Retusche","BOOL",128,116,8,8
FF_AddControl "Bilder ausrichten","Retuscheaufruf","STATIC",139,115,42,10
FF_AddControl "Bilder ausrichten","?|","BUTTON",182,115,10,10
FF_AddControl "Bilder ausrichten","Neuer Name + 2-st. Nummer","GROUP",5,41,115,24
FF_AddControl "Bilder ausrichten","flag_NeuerName","BOOL",94,40,8,8
FF_SetControlStyle "Bilder ausrichten","flag_NeuerName",16384
FF_AddControl "Bilder ausrichten","NeuerNameTxt","SLEDIT",10,51,105,10
FF_AddControl "Bilder ausrichten","fester Speicherort","GROUP",5,70,195,23
FF_AddControl "Bilder ausrichten","flag_Speicherort","BOOL",94,69,8,8
FF_AddControl "Bilder ausrichten","SpeicherortTxt","SLEDIT",10,79,170,10
FF_SetControlStyle "Bilder ausrichten","SpeicherortTxt",2048
FF_AddControl "Bilder ausrichten","...","BUTTON",184,79,12,10
FF_AddControl "Bilder ausrichten","Meldung","IMAGE",3,96,199,15
FF_AddControl "Bilder ausrichten","?","BUTTON",9,129,11,11
FF_AddControl "Bilder ausrichten","|","STATIC",22,129,25,11
FF_SetControlStyle "Bilder ausrichten","|",1
FF_AddControl "Bilder ausrichten","Update","BUTTON",50,129,33,11
FF_AddControl "Bilder ausrichten","Abbrechen","BUTTON",121,129,33,11
FF_AddControl "Bilder ausrichten","Start","BUTTON",162,129,33,11
FF_AddControl "Bilder ausrichten","&delete","BUTTON",5,5,1,1
FF_AddControl "Bilder ausrichten","flag_Beschnitt","BOOL",132,53,8,8
FF_AddControl "Bilder ausrichten","Beschnitt +","STATIC",143,52,30,10
FF_AddControl "Bilder ausrichten","BS_Wert","SLEDIT",174,52,15,10
FF_SetControlStyle "Bilder ausrichten","BS_Wert",8193
FF_AddControl "Bilder ausrichten","px","STATIC",191,52,8,10
'** End Dialog Bilder ausrichten **

ListArray = split(BfrmtAuswahl,",")
for each element in ListArray
	FF_SetControl "Bilder ausrichten","Bfrmt",element
next

FF_SetControl "Bilder ausrichten","Meldung",mldAllgemein

call RegistryLesen

if flag_NeuerName = 1 then
	FF_EnableControl "Bilder ausrichten","flag_Praefix",false
	FF_EnableControl "Bilder ausrichten","PraefixTxt",false
	FF_EnableControl "Bilder ausrichten","flag_Suffix",false
	FF_EnableControl "Bilder ausrichten","SuffixTxt",false
end if

'Tooltips
if Version_OK("3.30.06") then
	FF_SetControlTooltip "Bilder ausrichten","...", "" &_
						 "Auswahl des Speicherorts"
	FF_SetControlTooltip "Bilder ausrichten","?", "" &_
						 "Anzeige der Kurzbeschreibung als PDF-Datei," & vbNewLine & _
						 "vorausgesetzt es ist ein PDF-Reader installiert." & vbNewLine & _
						 "Anderenfalls wird eine gekrzte Textversion angezeigt."
	FF_SetControlTooltip "Bilder ausrichten","Update", "" &_
						 "Prfung ob eine neue Version vorliegt"
	FF_SetControlTooltip "Bilder ausrichten","Abbrechen", "" &_
						 "Das Skript wird beendet"
	FF_SetControlTooltip "Bilder ausrichten","Start", "" &_
						 "Das Ausrichten wird gestartet"
end if

FF_SetTooltipDelay 4000
FF_ActivateControl "Bilder ausrichten","&delete"
FF_SetDialogTimer "Bilder ausrichten", 100

Do
	Abbruch = false

	'Tooltips
	if Version_OK("3.30.06") then
		FF_SetControlTooltip "Bilder ausrichten","SpeicherortTxt", "" &_
						 	SpeicherortTxt
	end if

	Select Case FF_ShowDialog ("Bilder ausrichten")
	Case "TIMER"
		FF_SetControl "Bilder ausrichten" ,"|", "V " & Skriptversion
		FF_SetDialogTimer "Bilder ausrichten", 0
	Case "&delete"
		Antwort = msgbox("Soll das Skript " & objFS.GetFileName(Skriptname) & vbNewline & _
						 "wirklich gelscht werden?", _
						 vbYesNo + vbQuestion,"Sicherheitsabfrage")
		if Antwort = vbYes then
			SkriptKill = true
			exit do
		end if
	Case "flag_sBCA"
		FF_SetControl "Bilder ausrichten" ,"flag_sBCA",1
		FF_SetControl "Bilder ausrichten" ,"flag_sBaB",0
	Case "flag_sBaB"
		FF_SetControl "Bilder ausrichten" ,"flag_sBCA",0
		FF_SetControl "Bilder ausrichten" ,"flag_sBaB",1
	Case "flag_NeuerName"
		if FF_GetControl ("Bilder ausrichten","flag_NeuerName") = 1 then
			FF_EnableControl "Bilder ausrichten","flag_Praefix",false
			FF_EnableControl "Bilder ausrichten","PraefixTxt",false
			FF_EnableControl "Bilder ausrichten","flag_Suffix",false
			FF_EnableControl "Bilder ausrichten","SuffixTxt",false
		else
			FF_EnableControl "Bilder ausrichten","flag_Praefix",true
			FF_EnableControl "Bilder ausrichten","PraefixTxt",true
			FF_EnableControl "Bilder ausrichten","flag_Suffix",true
			FF_EnableControl "Bilder ausrichten","SuffixTxt",true
		end if
	Case "flag_Praefix"
		FF_SetControl "Bilder ausrichten" ,"flag_Praefix",1
		FF_SetControl "Bilder ausrichten" ,"flag_Suffix",0
	Case "flag_Suffix"
		FF_SetControl "Bilder ausrichten" ,"flag_Praefix",0
		FF_SetControl "Bilder ausrichten" ,"flag_Suffix",1
	Case "?|"
		WshShell.Popup msg,,"Erluterung zum Retuscheaufruf"
	Case "..."
		Dim Ziel
		FF_SetCurrentPath SpeicherortTxt
		Ziel = FF_EnterPath(false,"Wahl des Ablageordners")
		if len(Ziel) > 2 then
			SpeicherortTxt = Ziel
			FF_SetControl "Bilder ausrichten","SpeicherortTxt",SpeicherortTxt
		end if
	Case"?"
		Anzeige = """" & FF_GetScriptPath & "\MeckiScript\Bildausrichtung\Bilder ausrichten.pdf" & """"
		on error resume next
		WshShell.Run Anzeige,1,false
		if err <> 0 then
			msgbox "Die Kurzbeschreibung konnte nicht als PDF-Datei geffnet werden." & vbNewLine & _
				   "Die Datei ist gelscht oder es ist kein PDF-Reader installiert (?)." & vbNewLine & vbNewLine &_
				   "Ersatzweise erfolgt eine Textanzeige!",vbExclamation,"Hinweis"
			err.clear
			
			call TextErmittlung ("'** Start Text **","'** Textende **")
			call TextAnzeige (LaengeMax * 2.6,200)
		end if
		on error GoTo 0
	Case"Update"
		SkriptEnde = false
		call Update
		if SkriptEnde then exit do
	Case "Abbrechen","CANCEL"
		exit do
	Case "Start"
		FF_SetControl "Bilder ausrichten","Meldung",mldStart
		FF_RefreshDialog "Bilder ausrichten"
		
		call WerteAuslesen
		infArray = split(infiles,vbNewline)
		
		if ubound(infArray) < 1 then
			msgbox "Es mssen mindestens 2 Bilder ausgewhlt werden!",vbInformation,"Hinweis"
		else
			call Kontrolle
			if not Abbruch then
				call InOut
				FF_SetControl "Bilder ausrichten","Meldung",mldAusrichten
				FF_RefreshDialog "Bilder ausrichten"
				call Ausrichten
				if not Abbruch and flag_Retusche = 1 then
					FF_SetControl "Bilder ausrichten","Meldung",mldRetusche
					FF_RefreshDialog "Bilder ausrichten"
					call Helligkeit
'					msgbox	"Das Bild" & vbNewLine & hBild & vbNewLine &_
'							"ist das hellste und das Bild" & vbNewline & dBild & vbNewline & _
'							"das dunkelste.",vbInformation,"Ergebnis"
					retAufruf = true
					exit do
				else
					exit do
				end if
			end if
		end if
		FF_SetControl "Bilder ausrichten","Meldung",mldAllgemein
		FF_RefreshDialog "Bilder ausrichten"
	Case Else
	End Select
loop

call RegistrySchreiben
FF_CloseDialog ("Bilder ausrichten")

if SkriptKill then call KillSkript
if retAufruf then call Retuscheaufruf

End Sub
'------------------------------------------------------------------------
Sub WerteAuslesen

'Auswahl
if FF_GetControl ("Bilder ausrichten","flag_sBCA") = 1 then Auswahl = 1	'markierte Dateien der Computeransicht
if FF_GetControl ("Bilder ausrichten","flag_sBaB") = 1 then Auswahl = 3	'markierte Dateien der aktuellen Bilderliste
infiles = FF_GetSelection(Auswahl)

'Ausgabe
Bfrmt = FF_GetControl ("Bilder ausrichten","Bfrmt")
flag_Praefix = FF_GetControl ("Bilder ausrichten","flag_Praefix")
PraefixTxt = FF_GetControl ("Bilder ausrichten","PraefixTxt")
flag_Suffix = FF_GetControl ("Bilder ausrichten","flag_Suffix")
SuffixTxt = FF_GetControl ("Bilder ausrichten","SuffixTxt")
flag_Beschnitt = FF_GetControl ("Bilder ausrichten","flag_Beschnitt")
BS_Wert = FF_GetControl ("Bilder ausrichten","BS_Wert")
if BS_Wert = "" then BS_Wert = 0
flag_Retusche = FF_GetControl ("Bilder ausrichten","flag_Retusche")

'Neuer Name
flag_NeuerName = FF_GetControl ("Bilder ausrichten","flag_NeuerName")
NeuerNameTxt = FF_GetControl ("Bilder ausrichten","NeuerNameTxt")

'Speicherort
flag_Speicherort = FF_GetControl ("Bilder ausrichten","flag_Speicherort")
SpeicherortTxt = FF_GetControl ("Bilder ausrichten","SpeicherortTxt")

End Sub
'------------------------------------------------------------------------
Sub Kontrolle

if flag_NeuerName = 1 then
	if len(NeuerNameTxt) = 0 then
		msgbox "Es ist kein 'Neuer Name' eingetragen!",vbExclamation,"Abbruch"
		Abbruch = true : exit sub
	end if
else
	if flag_Praefix = 1 and len(PraefixTxt) = 0 then
		msgbox "Es ist kein Prfixtext eingetragen!",vbExclamation,"Abbruch"
		Abbruch = true : exit sub
	end if
	if flag_Suffix = 1 and len(SuffixTxt) = 0 then
		msgbox "Es ist kein Suffixtext eingetragen!",vbExclamation,"Abbruch"
		Abbruch = true : exit sub
	end if
end if

if flag_Beschnitt = 1 and BS_Wert = 0 then
	msgbox "Sollen die Bilder beschnitten werden," & vbNewLine &_
			"muss eine Pixelanzahl grer Null eingegeben werden!",vbExclamation,"Abbruch"
	Abbruch = true : exit sub
end if

if flag_Speicherort = 1 then
	if not objFS.FolderExists(SpeicherortTxt) then
		msgbox "Der angegbene Speicherort existiert nicht!",vbExclamation,"Abbruch"
		Abbruch = true : exit sub
	end if
end if

End Sub
'------------------------------------------------------------------------
Sub RegistryLesen
'Schlsselname = HKEY_CURRENT_USER\Software\Joachim Koopmann Software\FixFoto\Script\ & RegSchluessel

'### Werte auslesen

'Auswahl
Auswahl = FF_GetProfile (RegSchluessel,"Auswahl")
if Auswahl = "" then Auswahl = 1

'Ausgabe
Bfrmt = FF_GetProfile (RegSchluessel,"Bfrmt")
if Bfrmt = "" then Bfrmt = "ident"

flag_Praefix = FF_GetProfile (RegSchluessel,"flag_Praefix")
if flag_Praefix = "" then flag_Praefix = 1

PraefixTxt = FF_GetProfile (RegSchluessel,"PraefixTxt")
if PraefixTxt = "" then PraefixTxt = "matched_"

flag_Suffix = FF_GetProfile (RegSchluessel,"flag_Suffix")
if flag_Suffix = "" then flag_Suffix = 0

SuffixTxt = FF_GetProfile (RegSchluessel,"SuffixTxt")
if SuffixTxt = "" then SuffixTxt = "_matched"

flag_Beschnitt = FF_GetProfile (RegSchluessel,"flag_Beschnitt")
if flag_Beschnitt = "" then flag_Beschnitt = 0

BS_Wert = FF_GetProfile (RegSchluessel,"BS_Wert")
if BS_Wert = "" then BS_Wert = 10

flag_Retusche = FF_GetProfile (RegSchluessel,"flag_Retusche")
if flag_Retusche = "" then flag_Retusche = 0

'Neuer Name
flag_NeuerName = FF_GetProfile (RegSchluessel,"flag_NeuerName")
if flag_NeuerName = "" then flag_NeuerName = 0

NeuerNameTxt = FF_GetProfile (RegSchluessel,"NeuerNameTxt")
if NeuerNameTxt = "" then NeuerNameTxt = "Matched"

'Speicherort
flag_Speicherort = FF_GetProfile (RegSchluessel,"flag_Speicherort")
if flag_Speicherort = "" then flag_Speicherort = 0

SpeicherortTxt = FF_GetProfile (RegSchluessel,"SpeicherortTxt")
if SpeicherortTxt = "" then SpeicherortTxt = objFS.GetSpecialFolder(2)


'### Werte eintragen

'Auswahl
select case Auswahl
	Case 1
		FF_SetControl "Bilder ausrichten","flag_sBCA",1
	Case 3
		FF_SetControl "Bilder ausrichten","flag_sBaB",1
Case else
End select

'Ausgabe
FF_SetControl "Bilder ausrichten","Bfrmt",Bfrmt
FF_SetControl "Bilder ausrichten","flag_Praefix",flag_Praefix
FF_SetControl "Bilder ausrichten","PraefixTxt",PraefixTxt
FF_SetControl "Bilder ausrichten","flag_Suffix",flag_Suffix
FF_SetControl "Bilder ausrichten","SuffixTxt",SuffixTxt
FF_SetControl "Bilder ausrichten","flag_Beschnitt",flag_Beschnitt
FF_SetControl "Bilder ausrichten","BS_Wert",BS_Wert
FF_SetControl "Bilder ausrichten","flag_Retusche",flag_Retusche

'Neuer Name
FF_SetControl "Bilder ausrichten","flag_NeuerName",flag_NeuerName
FF_SetControl "Bilder ausrichten","NeuerNameTxt",NeuerNameTxt

'Speicherort
FF_SetControl "Bilder ausrichten","flag_Speicherort",flag_Speicherort
FF_SetControl "Bilder ausrichten","SpeicherortTxt",SpeicherortTxt

End Sub
'------------------------------------------------------------------------
Sub RegistrySchreiben
'Schlsselname = HKEY_CURRENT_USER\Software\Joachim Koopmann Software\FixFoto\Script\ & RegSchluessel

call WerteAuslesen

'Werte schreiben
FF_WriteProfile RegSchluessel,"Auswahl",Auswahl
FF_WriteProfile RegSchluessel,"Bfrmt",Bfrmt
FF_WriteProfile RegSchluessel,"flag_Praefix",flag_Praefix
FF_WriteProfile RegSchluessel,"PraefixTxt",PraefixTxt
FF_WriteProfile RegSchluessel,"flag_Suffix",flag_Suffix
FF_WriteProfile RegSchluessel,"SuffixTxt",SuffixTxt
FF_WriteProfile RegSchluessel,"flag_Beschnitt",flag_Beschnitt
FF_WriteProfile RegSchluessel,"BS_Wert",BS_Wert
FF_WriteProfile RegSchluessel,"flag_Retusche",flag_Retusche
FF_WriteProfile RegSchluessel,"flag_NeuerName",flag_NeuerName
FF_WriteProfile RegSchluessel,"NeuerNameTxt",NeuerNameTxt
FF_WriteProfile RegSchluessel,"flag_Speicherort",flag_Speicherort
FF_WriteProfile RegSchluessel,"SpeicherortTxt",SpeicherortTxt

End Sub
'------------------------------------------------------------------------
Sub InOut
'Definition der outfiles

Dim dir,file,ext,n,BildName

outfiles = ""
for n = 0 to ubound(infArray)
	if flag_Speicherort = 1 then
		dir = SpeicherortTxt & "\"
	else
		dir = objFS.GetParentFolderName(infArray(n)) & "\"
	end if
	
	if flag_NeuerName = 1 then
		if n = 0 then
			file = NeuerNameTxt & "_01"
		elseif n > 0 and n < 9 then
			file = NeuerNameTxt & "_0" & n +1
		else
			file = NeuerNameTxt & "_"  & n +1
		end if
	else
		if flag_Praefix = 1 then
			file = PraefixTxt & objFS.GetBaseName(infArray(n))
		else
			file = objFS.GetBaseName(infArray(n)) & SuffixTxt
		end if
	end if
	
	if Bfrmt = "ident" then
		ext = "." & objFS.GetExtensionName(infArray(n))
	else
		ext = "." & Bfrmt
	end if
	
	if len(outfiles) = 0 then
		outfiles = dir & file & ext
	else
		outfiles = outfiles & vbNewline & dir & file & ext
	end if
next

'outfiles prfen ob bereits vorhanden, ggf. nummerieren mit (1), (2) usw.
outfArray = split(outfiles,vbNewLine)
outfiles = "" : n = 1
for each element in outfArray
	if objFS.FileExists(element) then
		do
			BildName = 	objFS.GetParentFolderName(element) & "\" &_
						objFS.GetBaseName(element) & "(" & n & ")." &_
						objFS.GetExtensionName(element)
			if not objFS.FileExists(BildName) then exit do
			n = n +1
		loop
	else
		BildName = element
	end if
	
	if len(outfiles) = 0 then
		outfiles = BildName
	else
		outfiles = outfiles & vbNewLine & BildName
	end if
next
outfArray = split(outfiles,vbNewLine)

End Sub
'------------------------------------------------------------------------
Sub Ausrichten
Dim n
Dim Ergebnis : Ergebnis = true

'Bilder ausrichten
on error resume next
Ergebnis = FF_MatchImages(infiles,outfiles)
if err.number <> 0 then 
	msgBox "Fehler Nr. " & CStr(Err.Number) & vbNewLine & Err.Description
	Ergebnis = false
end if
on error goto 0

'Kontrolle ob alle ausgerichteten Bilder vorhanden
if Ergebnis then
	for each element in outfArray
		if not objFS.FileExists(element) then
			Ergebnis = false
			exit for
		end if
	next
end if

'bei negativem Ergebnis der Kontrolle angelegte Bilder wieder lschen
if not Ergebnis then
	for each element in outfArray
		if objFS.FileExists(element) then
			objFS.DeleteFile element,true
		end if
	next
	msgbox "Leider konnten die ausgewhlten Bilder nicht ausgerichtet werden.",vbExclamation,"Schlussmeldung"
	Abbruch = true : exit sub	
end if

'Exif-Daten von den Ursprungsbildern in die ausgerichteten Bilder bertragen
for n = 0 to ubound(infArray)
	if ucase(objFS.GetExtensionName(infArray(n))) = "JPG" then
		FF_LoadImage(infArray(n))
		if FF_HasExif and (Bfrmt = "JPG" or Bfrmt = "ident") then
			FF_SaveExif(outfArray(n))
		end if
		if FF_HasIPTC and (Bfrmt = "JPG" or Bfrmt = "ident") then
			FF_SaveIPTC(outfArray(n))
		end if
	end if
next

'Bilder beschneiden
if flag_Beschnitt = 1 then call Beschnitt

'Schlussmeldung
if flag_Retusche = 0 then
	msgbox ubound(infArray) +1 & " Bilder wurden erfolgreich ausgerichtet!",vbInformation,"Schlussmeldung"
end if

End Sub
'------------------------------------------------------------------------
Sub Beschnitt
Dim b,h,x,y,li,re,ob,ut,MAXli,MAXre,MAXob,MAXut
MAXli = 0 : MAXre = 0 : MAXob = 0 : MAXut = 0

on error resume next
for each element in outfArray
	FF_LoadImage element

	b = FF_GetImageWidth
	h = FF_GetImageHeight

	'links
	x = 0 : y = h \ 2
	Do
		if FF_GetPixel(x,y) <> 0 then li = x : exit do
		x = x +1
		if x >= b then li = 0 : exit do
	Loop
	if li > MAXli then MAXli = li

	'rechts
	x = b : y = h \ 2
	Do
		if FF_GetPixel(x,y) <> 0 then re = b - x : exit do
		x = x -1
		if x <= 0 then re = 0 : exit do
	Loop
	if re > MAXre then MAXre = re
	
	'oben
	x = b \ 2 : y = 0
	Do
		if FF_GetPixel(x,y) <> 0 then ob = y : exit do
		y = y +1
		if y >= h then ob = 0 : exit do
	Loop
	if ob > MAXob then MAXob = ob
	
	'unten
	x = b \ 2 : y = h
	Do
		if FF_GetPixel(x,y) <> 0 then ut = h - y : exit do
		y = y -1
		if y <= 0 then ut = 0 : exit do
	Loop
	if ut > MAXut then MAXut = ut
	
next

if err <> 0 then
	msgbox "Die Schnittbreite konnte nicht automatisch ermittelt werden!" & vbNewLine &_
			"Es erfolgt daher kein Beschnitt!",vbInformation,"Hinweis"
else
	MAXli = MAXli + BS_Wert : MAXre = MAXre + BS_Wert
	MAXob = MAXob + BS_Wert : MAXut = MAXut + BS_Wert
	for each element in outfArray
		FF_LoadImage element
		FF_Crop MAXli,MAXob,b - MAXli - MAXre,h - MAXob - MAXut
		FF_SaveImage element,0
	next
end if

on error goto 0

End Sub
'------------------------------------------------------------------------
Sub Helligkeit
Dim TmpFile,n,x,y,h,hMin,hMax,nMin,nMax

hMax = 0 : hMin = 16777215 *9
TmpFile = objFS.GetSpecialFolder(2) & "\TempFile.jpg"

for n = 0 to ubound(outfArray)

	FF_LoadImage outfArray(n)

	FF_Scale 1000,1000,false
	FF_CreateContrastImage(200)

	FF_SaveImage TmpFile,0
	FF_LoadImage TmpFile
	
	h = 0
	for x = 300 to 700 step 200
    	for y = 300 to 700 step 200
			h = h + FF_GetPixel(x,y)
		next
	next
	if h > hMax then hMax = h : nMax = n
	if h < hMin then hMin = h : nMin = n
next

if objFS.FileExists(TmpFile) then objFS.DeleteFile TmpFile,true

hBild = outfArray(nMin)	'hellstes Bild
dBild = outfArray(nMax)	'dunkelstes Bild

End Sub
'------------------------------------------------------------------------
Sub Retuscheaufruf
Dim mode,size,hard,blend

'mode =	0 = Auhellen
'		1 = Abdunkeln
'		2 = Rote Augen entfernen
'		3 = Frben
'		4 = Reparieren
'		5 = Entfernen
'		6 = Schrfen
'		7 = Weichzeichner
'		8 = Quelle klonen
'		9 = Ziel klonen

FF_LoadImage dBild

mode  = 8
size  = FF_GetImageWidth \ 30 : if size > 255 then size = 255
hard  = 0
blend = 30

FF_Retouch hBild,mode,size,hard,blend
FF_Reload

End Sub
'------------------------------------------------------------------------

'************************************************************************
'************************************************************************
'Prfung der FF-Version
'************************************************************************
Function Version_OK(MinVersion)
dim VersNr

 VersNr=split(MinVersion,".")
 Version_OK=FF_GetMajor * 1000 + FF_GetMinor + FF_GetBuild / 1000 >=_
     		VersNr(0) * 1000 + VersNr(1) + VersNr(2) / 1000

End Function
'************************************************************************
'Lsch-Funktion
'************************************************************************
Sub KillSkript
'Skript mit allen Komponenten entfernen

Dim SPfad
Skriptname = FF_GetScriptPath & "\" & Skriptname

'### FixFotoScript.ini bereinigen
TempFile = FF_GetFFPathEx(1) & "\FixFotoScript.ini"
if objFS.FileExists(TempFile) then
	call IniBereinigung
	if Abbruch then exit sub
else
	msgbox 	"Die Datei FixFotoScript.ini konnte nicht gefunden werden." & vbNewLine & _
			"Der Lschvorgang wird abgebrochen!",vbExclamation,"Hinweis"
	exit sub
end if

'### zip-Archiv auf Wunsch sichern, dann lschen
TempFile = FF_GetScriptPath & "\" & objFS.GetBaseName(Skriptname) & ".zip"
if objFS.FileExists(TempFile) then
	Antwort = msgbox("Soll das Archiv " & objFS.GetBaseName(Skriptname) & ".zip" & _
			 " gesichert werden?",vbYesNo + vbQuestion,"Sicherheitskopie")
	if Antwort = vbYes then
		SPfad = FF_EnterPath(true,"Wo soll die Sicherheitskopie angelegt werden?")
		if SPfad = "" then
			msgbox "Das Lschen des Skripts wird abgebrochen!",vbExclamation,"Hinweis"
			exit sub
		end if
		SPfad = SPfad & "\" & objFS.GetBaseName(Skriptname) & ".zip"
		objFS.CopyFile Tempfile, SPfad, true
	end if
	objFS.DeleteFile TempFile,true
end if

'### Skriptdatei lschen
objFS.DeleteFile Skriptname,true

'### beigepackten Ordner lschen
TempFile = FF_GetScriptPath & "\MeckiScript\BildAusrichtung"
if objFS.FolderExists(TempFile) then objFS.DeleteFolder TempFile,true

'### Registry-Daten lschen
TempFile = "HKEY_CURRENT_USER\Software\Joachim Koopmann Software\FixFoto\Script\" & RegSchluessel & "\"
WshShell.RegDelete(TempFile)

'### Fertigmeldung
msgbox "Das Skript " & objFS.GetFileName(Skriptname) & vbNewLine & "wurde mit allen Komponenten gelscht!" & vbNewLine & _
	   "Es wird empfohlen die 'Automatische Skriptkonfiguration' aufzurufen.",vbExclamation,"Hinweis"

End Sub
'------------------------------------------------------------------------
Sub IniBereinigung
'FixFotoScript.ini - Bereinigung

Dim Zeile, zNr,Anfang, Ende, DateiTmp, ZielZeile, tmpString

DateiTmp =  FF_GetFFPathEx(1) & "\FixFotoScript.tmp"

'### Wo befindet sich der Eintrag zum Skript?
Set Zeile = objFS.OpenTextFile(TempFile, ForReading)

zNr = 0
do Until Zeile.AtEndOfStream
	tmpString = Zeile.ReadLine
	zNr = zNr + 1
	if tmpString = "[Script]" then Anfang = zNr
	if tmpString = "File=.\" & objFS.GetFileName(Skriptname) then
		Ende = zNr
		exit do	
	end if
loop 
Zeile.Close

if Ende <= Anfang then
	msgbox 	"Die Datei FixFotoScript.ini konnte nicht bereinigt werden." & vbNewLine & _
		"Der Lschvorgang wird abgebrochen!",vbExclamation,"Hinweis"
	Abbruch = true
	exit sub
end if

'### Zeilen ohne skriptbezogene Zeilen in DateiTmp bertragen
Set Zeile = objFS.OpenTextFile(TempFile, ForReading)
Set ZielZeile  = objFS.CreateTextFile(DateiTmp, True)

zNr = 0
do Until Zeile.AtEndOfStream
	tmpString = Zeile.ReadLine
	zNr = zNr + 1
	if zNr < Anfang or zNr > Ende then
		ZielZeile.WriteLine tmpString
	end if
loop 

Zeile.Close
ZielZeile.Close

'### Umkopieren von DateiTmp nach FixFotoScript.ini (TempFile)
objFS.CopyFile DateiTmp, TempFile, True
objFS.DeleteFile (DateiTmp)

End Sub
'************************************************************************
'Update-Funktion
'************************************************************************
Sub Update
Dim Antwort

call Versionsermittlung_url

if not Abbruch then
	SkriptV_Zahl = Replace(SkriptVersion,".","") *1
	
	if UrlV_Zahl = SkriptV_Zahl then
		msgbox "Die Version " & SkriptVersion & " ist aktuell!",vbInformation,"Versionsmeldung"
	elseif SkriptV_Zahl < UrlV_Zahl then
		Antwort = msgbox("Die Skriptversion " & SkriptVersion & " ist nicht mehr aktuell!" & vbNewLine &_
				"Es steht die Version " & UrlVersion & " zum Download bereit." & vbNewLine & vbNewLine & _
				"Soll die Downloadseite aufgerufen werden?",vbQuestion + vbYesNo,"Versionsmeldung")
		if Antwort = vbYes then
			on error resume next
			WshShell.Run SkriptUrl,1,false
			if err <> 0 then
				msgbox "Die Downloadseite wurde nicht gefunden!",vbExclamation,"Hinweis"
			else
				SkriptEnde = true
			end if
			on error goto 0
		end if
	else
		msgbox 	"Es liegt ein Fehler in den Versionsangaben vor." & vbNewLine &_
				"Die Skriptversion " & SkriptVersion & " ist grer als die auf" & vbNewLine &_
				"der Downloadseite angegebene Version " & UrlVersion & ".",vbInformation,"Fehlermeldung"
	end if
end if

End Sub
'------------------------------------------------------------------------
Sub Versionsermittlung_url

Dim Inhalt,Start,Zeit,pos1,pos2,n
Dim xml, Fehler
Fehler = false

on error resume next
Set xml = CreateObject("Microsoft.XMLHTTP")
xml.Open "Get",SkriptUrl,false
xml.Send

Inhalt = xml.responseText
'WshShell.Popup Inhalt,,"Kurzbeschreibung"
if err > 0 then
	Fehler = true
else
	'Version suchen und anzeigen
	pos1 = instr(Inhalt,"Version:")
'Msgbox pos1
	if pos1 > 0 then
		pos2 = instr(pos1 ,Inhalt,"<br")
		if pos2 > 0 then
			UrlVersion = trim(mid(Inhalt,pos1,pos2-pos1))
			'Msgbox "Aktuell ist die " & UrlVersion,vbInformation,"Information"
		else
			Fehler = true
		end if
	else
		Fehler = true
	end if
end if

Set xml = nothing

if Fehler then
	msgbox  "Die Versionsangabe wurde nicht gefunden!" & vbNewLine &_
			"Mglicherweise funktioniert der Internetaufruf nicht." & vbNewLine & vbNewLine & _
			"Am besten nochmal probieren!",vbExclamation,"Fehlermeldung"
	Abbruch = true
	exit sub
end if

'Version als Zahl
pos1 = instr(UrlVersion," ")
if pos1 = 0 then pos1 = 7
UrlVersion = trim(mid(UrlVersion,pos1+1))
UrlV_Zahl = Replace(UrlVersion,".","") *1

End Sub
'************************************************************************
'Text auslesen
'************************************************************************
Sub TextErmittlung (T_Anfang,T_Ende)
'Text auslesen von T-Anfang bis T-Ende

Dim Skript, Anfang, Ende, Zeile

Set Skript = objFS.OpenTextFile(FF_GetScriptPath & "\" & SkriptName, ForReading, False)

Do While Skript.AtEndOfStream <> True
	Zeile = Skript.ReadLine

	if instr(Zeile,T_Ende) > 0 and Anfang then
		Ende = true
		exit do
	end if

	if Anfang then
		Text = Text & mid(Zeile,2) & vbNewLine
		if len(Zeile) > LaengeMax then LaengeMax = len(Zeile)
	end if

	if instr(Zeile,T_Anfang) > 0 then Anfang = true
Loop

Skript.Close

if not Anfang or not Ende then Text = ""

End Sub
'------------------------------------------------------------------------
Sub TextAnzeige (D_Breite,D_Hoehe)
'Dialog mit EDIT-Steuerelement zur Textanzeige

const ES_READONLY = 2048    	'Stilkonstanten fr EDIT
const WS_VSCROLL = 2097152

const dlg = "Kurzbeschreibung"	'Benennung der Anzeige
 
'Dialog mit Textelement
'Stil: ReadOnly und Vertikal Skrollen, wenn Textblock hher als das Textelement
FF_AddDialog dlg,D_Breite,D_Hoehe
FF_AddControl dlg,"Beschreibung","EDIT",0,0,D_Breite,D_Hoehe-20
FF_SetControlStyle dlg,"Beschreibung", ES_READONLY or WS_VSCROLL
FF_AddControl dlg,"OK","BUTTON",D_Breite/2-15,D_Hoehe-15,30,10

FF_SetControl dlg,"Beschreibung",Text    'Textanzeige

do
	Select Case FF_ShowDialog (dlg)
		Case "OK","CANCEL"
			exit do
	end select
loop

FF_CloseDialog dlg
 
End Sub
'************************************************************************
'************************************************************************
